@@ -36,6 +36,7 @@ import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
 import org.apache.poi.util.LocaleUtil;
 import org.apache.poi.util.Units;
 import org.apache.poi.wp.usermodel.HeaderFooterType;
+import org.apache.poi.xddf.usermodel.chart.XDDFChart;
 import org.apache.poi.xwpf.XWPFTestDataSamples;
 import org.apache.poi.xwpf.model.XWPFHeaderFooterPolicy;
 import org.junit.jupiter.api.AfterEach;
@@ -552,7 +553,7 @@ class TestXWPFRun {
         assertEquals(0, doc.getAllPictures().size());
         assertEquals(0, r.getEmbeddedPictures().size());
 
-        r.addPicture(new ByteArrayInputStream(new byte[0]), Document.PICTURE_TYPE_JPEG, "test.jpg", 21, 32);
+        r.addPicture(new ByteArrayInputStream(new byte[0]), PictureType.JPEG, "test.jpg", 21, 32);
 
         assertEquals(1, doc.getAllPictures().size());
         assertEquals(1, r.getEmbeddedPictures().size());
@@ -580,7 +581,7 @@ class TestXWPFRun {
             assertEquals(0, hdr.getAllPictures().size());
             assertEquals(0, r.getEmbeddedPictures().size());
 
-            r.addPicture(new ByteArrayInputStream(new byte[0]), Document.PICTURE_TYPE_JPEG, "test.jpg", 21, 32);
+            r.addPicture(new ByteArrayInputStream(new byte[0]), PictureType.JPEG, "test.jpg", 21, 32);
 
             assertEquals(1, hdr.getAllPictures().size());
             assertEquals(1, r.getEmbeddedPictures().size());
@@ -627,7 +628,7 @@ class TestXWPFRun {
         try (XWPFDocument document = new XWPFDocument()) {
 
             document.createParagraph().createRun().addPicture(
-                    new ByteArrayInputStream(image), Document.PICTURE_TYPE_JPEG, "test.jpg", Units.toEMU(300), Units.toEMU(100));
+                    new ByteArrayInputStream(image), PictureType.JPEG, "test.jpg", Units.toEMU(300), Units.toEMU(100));
 
             try (XWPFDocument docBack = writeOutAndReadBack(document)) {
                 List<XWPFPicture> pictures = docBack.getParagraphArray(0).getRuns().get(0).getEmbeddedPictures();
@@ -858,7 +859,7 @@ class TestXWPFRun {
             assertEquals(0, hdr.getAllPictures().size());
             assertEquals(0, r.getEmbeddedPictures().size());
 
-            r.addPicture(new ByteArrayInputStream(new byte[0]), Document.PICTURE_TYPE_JPEG, "test.jpg", 21, 32);
+            r.addPicture(new ByteArrayInputStream(new byte[0]), PictureType.JPEG, "test.jpg", 21, 32);
 
             assertEquals(1, hdr.getAllPictures().size());
             assertEquals(1, r.getEmbeddedPictures().size());
@@ -909,4 +910,34 @@ class TestXWPFRun {
         run.setText("TEST STRING");
         assertEquals(1, run.getNumberOfTexts());
     }
+
+    @Test
+    void testGetEmbeddedCharts() throws IOException {
+        try (XWPFDocument sampleDoc = XWPFTestDataSamples.openSampleDocument("61745.docx")) {
+            List<XWPFChart> charts = sampleDoc.getCharts();
+            assertEquals(2, charts.size());
+            List<XWPFChart> run1Charts = sampleDoc.getParagraphArray(0).getRuns().get(0).getEmbeddedCharts();
+            assertEquals(1, run1Charts.size());
+            assertEquals(charts.get(0), run1Charts.get(0));
+            List<XWPFChart> run2Charts = sampleDoc.getParagraphArray(1).getRuns().get(0).getEmbeddedCharts();
+            assertEquals(1, run2Charts.size());
+            assertEquals(charts.get(1), run2Charts.get(0));
+        }
+    }
+
+    @Test
+    void testAddChartGetEmbeddedCharts() throws InvalidFormatException, IOException {
+        XWPFRun run1 = p.createRun();
+        XWPFChart chart1 = doc.createChart(run1, XDDFChart.DEFAULT_WIDTH, XDDFChart.DEFAULT_HEIGHT);
+        assertEquals(1, run1.getEmbeddedCharts().size());
+        assertEquals(chart1, run1.getEmbeddedCharts().get(0));
+
+        XWPFRun run2 = p.createRun();
+        XWPFChart chart2 = doc.createChart(run2, XDDFChart.DEFAULT_WIDTH, XDDFChart.DEFAULT_HEIGHT);
+        assertEquals(1, run2.getEmbeddedCharts().size());
+        assertEquals(chart2, run2.getEmbeddedCharts().get(0));
+
+        XWPFRun run3 = p.createRun();
+        assertEquals(0, run3.getEmbeddedCharts().size());
+    }
 }
