@@ -162,6 +162,11 @@ public class DataFormatter {
      */
     private static final Pattern alternateGrouping = Pattern.compile("([#0]([^.#0])[#0]{3})");
 
+    /**
+     * For handling '0#' properly
+     */
+    private static final Pattern decimalFormatFix = Pattern.compile("0+#");
+
     /**
       * Cells formatted with a date or time format and which contain invalid date or time values
      *  show 255 pound signs ("#").
@@ -380,7 +385,7 @@ public class DataFormatter {
         // String formatStr = (i < formatBits.length) ? formatBits[i] : formatBits[0];
 
         // this replace is done to fix https://bz.apache.org/bugzilla/show_bug.cgi?id=63211
-        String formatStr = formatStrIn.replace("\\%", "\'%\'");
+        String formatStr = formatStrIn.replace("\\%", "'%'");
 
         // Excel supports 2+ part conditional data formats, eg positive/negative/zero,
         //  or (>1000),(>0),(0),(negative). As Java doesn't handle these kinds
@@ -700,7 +705,7 @@ public class DataFormatter {
 
     private String cleanFormatForNumber(String formatStrIn) {
         // this replace is done to fix https://bz.apache.org/bugzilla/show_bug.cgi?id=63211
-        String formatStr = formatStrIn.replace("\\%", "\'%\'");
+        String formatStr = formatStrIn.replace("\\%", "'%'");
 
         StringBuilder sb = new StringBuilder(formatStr);
 
@@ -803,6 +808,10 @@ public class DataFormatter {
             }
         }
 
+        boolean requiresScaling() {
+            return divider != null;
+        }
+
         private Object scaleInput(Object obj) {
             if (divider != null) {
                 if (obj instanceof BigDecimal) {
@@ -850,6 +859,11 @@ public class DataFormatter {
             }
         }
 
+        // Excel ignores leading zeros, but Java fails with an exception below
+        if (decimalFormatFix.matcher(format).matches()) {
+            format = "#";
+        }
+
         try {
             return new InternalDecimalFormatWithScale(format, symbols);
         } catch(IllegalArgumentException iae) {
@@ -955,12 +969,22 @@ public class DataFormatter {
         if (numberFormat == null) {
             return Double.toString(d);
         }
-        String formatted;
-        try {
-            //see https://github.com/apache/poi/pull/321 -- but this sometimes fails, thus the catch and retry
-            formatted = numberFormat.format(BigDecimal.valueOf(d));
-        } catch (NumberFormatException nfe) {
-            formatted = numberFormat.format(d);
+        String formatted = null;
+        if (numberFormat instanceof InternalDecimalFormatWithScale) {
+            InternalDecimalFormatWithScale idfws = (InternalDecimalFormatWithScale) numberFormat;
+            if (idfws.requiresScaling()) {
+                // hack for https://bz.apache.org/bugzilla/show_bug.cgi?id=69812
+                // the https://github.com/apache/poi/pull/321 hack causes problems here
+                formatted = idfws.format(d);
+            }
+        }
+        if (formatted == null) {
+            try {
+                //see https://github.com/apache/poi/pull/321 -- but this sometimes fails, thus the catch and retry
+                formatted = numberFormat.format(BigDecimal.valueOf(d));
+            } catch (NumberFormatException nfe) {
+                formatted = numberFormat.format(d);
+            }
         }
         return formatted.replaceFirst("E(\\d)", "E+$1"); // to match Excel's E-notation
     }
