@@ -93,11 +93,6 @@ public class SheetUtil {
         public CellType evaluateFormulaCell(Cell cell) { return cell.getCachedFormulaResultType(); }
     };
 
-    /**
-     * drawing context to measure text
-     */
-    private static FontRenderContext fontRenderContext = new FontRenderContext(null, true, true);
-
     /**
      * A system property which can be enabled to not fail when the
      * font-system is not available on the current machine.
@@ -214,13 +209,13 @@ public class SheetUtil {
                     String txt = line + defaultChar;
 
                     AttributedString str = new AttributedString(txt);
-                    copyAttributes(font, str, 0, txt.length());
+                    WithJavaDesktop.modifyAttributedString(str, font, 0, txt.length());
 
                     /*if (rt.numFormattingRuns() > 0) {
                         // TODO: support rich text fragments
                     }*/
 
-                    width = getCellWidth(defaultCharWidth, colspan, style, width, str);
+                    width = WithJavaDesktop.getCellWidth(defaultCharWidth, colspan, style, width, str);
                 }
             }
         } else {
@@ -238,48 +233,87 @@ public class SheetUtil {
             if(sval != null) {
                 String txt = sval + defaultChar;
                 AttributedString str = new AttributedString(txt);
-                copyAttributes(font, str, 0, txt.length());
+                WithJavaDesktop.modifyAttributedString(str, font, 0, txt.length());
 
-                width = getCellWidth(defaultCharWidth, colspan, style, width, str);
+                width = WithJavaDesktop.getCellWidth(defaultCharWidth, colspan, style, width, str);
             }
         }
         return width;
     }
 
-    /**
-     * Calculate the best-fit width for a cell
-     * If a merged cell spans multiple columns, evenly distribute the column width among those columns
-     *
-     * @param defaultCharWidth the width of a character using the default font in a workbook
-     * @param colspan the number of columns that is spanned by the cell (1 if the cell is not part of a merged region)
-     * @param style the cell style, which contains text rotation and indention information needed to compute the cell width
-     * @param minWidth the minimum best-fit width. This algorithm will only return values greater than or equal to the minimum width.
-     * @param str the text contained in the cell
-     * @return the best fit cell width
-     */
-    private static double getCellWidth(float defaultCharWidth, int colspan,
-            CellStyle style, double minWidth, AttributedString str) {
-        TextLayout layout = new TextLayout(str.getIterator(), fontRenderContext);
-        final Rectangle2D bounds;
-        if (style.getRotation() != 0) {
-            /*
-             * Transform the text using a scale so that its height is increased by a multiple of the leading,
-             * and then rotate the text before computing the bounds. The scale results in some whitespace around
-             * the unrotated top and bottom of the text that normally wouldn't be present if unscaled, but
-             * is added by the standard Excel autosize.
-             */
-            AffineTransform trans = new AffineTransform();
-            trans.concatenate(AffineTransform.getRotateInstance(style.getRotation()*2.0*Math.PI/360.0));
-            trans.concatenate(
-                    AffineTransform.getScaleInstance(1, fontHeightMultiple)
-            );
-            bounds = layout.getOutline(trans).getBounds();
-        } else {
-            bounds = layout.getBounds();
+    private static final class WithJavaDesktop {
+        /**
+         * drawing context to measure text
+         */
+        private static FontRenderContext fontRenderContext = new FontRenderContext(null, true, true);
+
+        /**
+         * Calculate the best-fit width for a cell
+         * If a merged cell spans multiple columns, evenly distribute the column width among those columns
+         *
+         * @param defaultCharWidth the width of a character using the default font in a workbook
+         * @param colspan the number of columns that is spanned by the cell (1 if the cell is not part of a merged region)
+         * @param style the cell style, which contains text rotation and indention information needed to compute the cell width
+         * @param minWidth the minimum best-fit width. This algorithm will only return values greater than or equal to the minimum width.
+         * @param str the text contained in the cell
+         * @return the best fit cell width
+         */
+        private static double getCellWidth(float defaultCharWidth, final int colspan,
+                final CellStyle style, final double minWidth, final AttributedString str) {
+            TextLayout layout;
+            try {
+                layout = new TextLayout(str.getIterator(), fontRenderContext);
+            } catch (Throwable t) {
+                if (shouldIgnoreMissingFontSystem(t)) {
+                    return FAILOVER_FUNCTION.apply(defaultCharWidth, colspan, style, minWidth, str);
+                }
+                throw t;
+            }
+            final Rectangle2D bounds;
+            if (style.getRotation() != 0) {
+                /*
+                 * Transform the text using a scale so that its height is increased by a multiple of the leading,
+                 * and then rotate the text before computing the bounds. The scale results in some whitespace around
+                 * the unrotated top and bottom of the text that normally wouldn't be present if unscaled, but
+                 * is added by the standard Excel autosize.
+                 */
+                AffineTransform trans = new AffineTransform();
+                trans.concatenate(AffineTransform.getRotateInstance(style.getRotation()*2.0*Math.PI/360.0));
+                trans.concatenate(
+                        AffineTransform.getScaleInstance(1, fontHeightMultiple)
+                );
+                bounds = layout.getOutline(trans).getBounds();
+            } else {
+                bounds = layout.getBounds();
+            }
+            // frameWidth accounts for leading spaces which is excluded from bounds.getWidth()
+            final double frameWidth = bounds.getX() + bounds.getWidth();
+            return Math.max(minWidth, ((frameWidth / colspan) / defaultCharWidth) + style.getIndention());
         }
-        // frameWidth accounts for leading spaces which is excluded from bounds.getWidth()
-        final double frameWidth = bounds.getX() + bounds.getWidth();
-        return Math.max(minWidth, ((frameWidth / colspan) / defaultCharWidth) + style.getIndention());
+
+        private static float getDefaultCharWidthAsFloat(AttributedString str) {
+            TextLayout layout = new TextLayout(str.getIterator(), fontRenderContext);
+            return layout.getAdvance();
+        }
+        
+        /**
+         * Copy text attributes from the supplied Font to Java2D AttributedString
+         */
+        private static void modifyAttributedString(AttributedString str, Font font, final int startIdx, final int endIdx) {
+            str.addAttribute(TextAttribute.FAMILY, font.getFontName(), startIdx, endIdx);
+            str.addAttribute(TextAttribute.SIZE, (float) font.getFontHeightInPoints());
+            if (font.getBold()) str.addAttribute(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, startIdx, endIdx);
+            if (font.getItalic() ) str.addAttribute(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, startIdx, endIdx);
+            if (font.getUnderline() == Font.U_SINGLE ) str.addAttribute(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, startIdx, endIdx);
+        }
+
+        private static boolean canComputeColumnWidth(Font font, AttributedString str) {
+            modifyAttributedString(str, font, 0, "1w".length());
+
+            TextLayout layout = new TextLayout(str.getIterator(), fontRenderContext);
+            return layout.getBounds().getWidth() > 0;
+        }
+        
     }
 
     /**
@@ -348,30 +382,63 @@ public class SheetUtil {
         Font defaultFont = wb.getFontAt( 0);
 
         AttributedString str = new AttributedString(String.valueOf(defaultChar));
-        copyAttributes(defaultFont, str, 0, 1);
         try {
-            TextLayout layout = new TextLayout(str.getIterator(), fontRenderContext);
-            return layout.getAdvance();
+            WithJavaDesktop.modifyAttributedString(str, defaultFont, 0, 1);
+            return WithJavaDesktop.getDefaultCharWidthAsFloat(str);
         } catch (Throwable t) {
-            // ignore exception and return a default char width if
-            // the ignore-feature is enabled and the exception indicates that
-            // the underlying font system is not available
-            if (ignoreMissingFontSystem && (
-                    // the three types of exception usually indicate here that the font
-                    // system is not fully installed, i.e. system libraries missing or
-                    // some JDK classes cannot be loaded
-                    t instanceof UnsatisfiedLinkError ||
-                    t instanceof NoClassDefFoundError ||
-                    t instanceof InternalError  ||
-                    // other fatal exceptions will always be rethrown
-                    !ExceptionUtil.isFatal(t))) {
+            if (shouldIgnoreMissingFontSystem(t)) {
                 return DEFAULT_CHAR_WIDTH;
             }
-
             throw t;
         }
     }
 
+    /**
+     * A function with 5 inputs and a return value.
+     * @param <A> the type of the first input to the function
+     * @param <B> the type of the second input to the function
+     * @param <C> the type of the third input to the function
+     * @param <D> the type of the fourth input to the function
+     * @param <E> the type of the fifth input to the function
+     * @param <R> the return type of the function
+     * @since POI 5.4.1
+     */
+    @FunctionalInterface
+    public interface Function5Arity<A, B, C, D, E, R> {
+        R apply(A a, B b, C c, D d, E e);
+    }
+
+    private static final Function5Arity<Float, Integer, CellStyle, Double, AttributedString, Float> DEFAULT_FAILOVER_FUNCTION =
+            (defaultCharWidth, colspan, style, minWidth, string) -> defaultCharWidth;
+
+    private static Function5Arity<Float, Integer, CellStyle, Double, AttributedString, Float> FAILOVER_FUNCTION =
+            DEFAULT_FAILOVER_FUNCTION;
+
+    /**
+     * Define a function to be used as a failover when the font system is not available.
+     * This function will be called with the default character width, the colspan, the cell style,
+     * the minimum width and the attributed string of the cell.
+     * <p>
+     *     The default function will return the default character width.
+     * </p>
+     * @since POI 5.4.1
+     */
+    public static void setFailoverFunction(Function5Arity<Float, Integer, CellStyle, Double, AttributedString, Float> failoverFunction) {
+        FAILOVER_FUNCTION = failoverFunction == null ? DEFAULT_FAILOVER_FUNCTION : failoverFunction;
+    }
+
+    private static boolean shouldIgnoreMissingFontSystem(final Throwable t) {
+        return ignoreMissingFontSystem && (
+                // the three types of exception usually indicate here that the font
+                // system is not fully installed, i.e. system libraries missing or
+                // some JDK classes cannot be loaded
+                t instanceof UnsatisfiedLinkError ||
+                        t instanceof NoClassDefFoundError ||
+                        t instanceof InternalError ||
+                        // other fatal exceptions will always be rethrown
+                        !ExceptionUtil.isFatal(t));
+    }
+
     /**
      * Compute width of a single cell in a row
      * Convenience method for {@link #getCellWidth}
@@ -414,22 +481,16 @@ public class SheetUtil {
     public static boolean canComputeColumnWidth(Font font) {
         // not sure what is the best value sample-here, only "1" did not work on some platforms...
         AttributedString str = new AttributedString("1w");
-        copyAttributes(font, str, 0, "1w".length());
-
-        TextLayout layout = new TextLayout(str.getIterator(), fontRenderContext);
-        return (layout.getBounds().getWidth() > 0);
+        try {
+            return WithJavaDesktop.canComputeColumnWidth(font, str);
+        } catch (Throwable t) {
+            if (shouldIgnoreMissingFontSystem(t)) {
+                return false;
+            }
+            throw t;
+        }
     }
 
-    /**
-     * Copy text attributes from the supplied Font to Java2D AttributedString
-     */
-    private static void copyAttributes(Font font, AttributedString str, @SuppressWarnings("SameParameterValue") int startIdx, int endIdx) {
-        str.addAttribute(TextAttribute.FAMILY, font.getFontName(), startIdx, endIdx);
-        str.addAttribute(TextAttribute.SIZE, (float)font.getFontHeightInPoints());
-        if (font.getBold()) str.addAttribute(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, startIdx, endIdx);
-        if (font.getItalic() ) str.addAttribute(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, startIdx, endIdx);
-        if (font.getUnderline() == Font.U_SINGLE ) str.addAttribute(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, startIdx, endIdx);
-    }
 
     /**
      * Return the cell, without taking account of merged regions.
@@ -501,11 +562,11 @@ public class SheetUtil {
     }
 
     protected static FontRenderContext getFontRenderContext() {
-        return fontRenderContext;
+        return WithJavaDesktop.fontRenderContext;
     }
 
     protected static void setFontRenderContext(FontRenderContext fontRenderContext) {
-        SheetUtil.fontRenderContext = fontRenderContext;
+        WithJavaDesktop.fontRenderContext = fontRenderContext;
     }
 
     private static boolean initIgnoreMissingFontSystemFlag() {
