@@ -107,6 +107,14 @@ public final class IOUtils {
         BYTE_ARRAY_MAX_OVERRIDE = maxOverride;
     }
 
+    /**
+     * @return The maximum number of bytes that should be possible to be allocated in one step.
+     * @since 5.4.1
+     */
+    public static int getByteArrayMaxOverride() {
+        return BYTE_ARRAY_MAX_OVERRIDE;
+    }
+
     /**
      * Peeks at the first 8 bytes of the stream. Returns those bytes, but
      *  with the stream unaffected. Requires a stream that supports mark/reset,
@@ -208,6 +216,27 @@ public final class IOUtils {
         return toByteArray(stream, length, maxLength, true, length != Integer.MAX_VALUE);
     }
 
+    /**
+     * Reads up to {@code length} bytes from the input stream, and returns the bytes read.
+     *
+     * @param stream The byte stream of data to read.
+     * @param length The maximum length to read, use {@link Integer#MAX_VALUE} to read the stream
+     *               until EOF
+     * @param maxLength if the input is equal to/longer than {@code maxLength} bytes,
+     *                  then throw an {@link IOException} complaining about the length.
+     *                  use {@link Integer#MAX_VALUE} to disable the check - if {@link #setByteArrayMaxOverride(int)} is
+     *                  set then that max of that value and this maxLength is used
+     * @return A byte array with the read bytes.
+     * @throws IOException If reading data fails or EOF is encountered too early for the given length.
+     * @throws RecordFormatException If the requested length is invalid.
+     * @since POI 5.4.1
+     */
+    public static byte[] toByteArray(InputStream stream, final long length, final int maxLength) throws IOException {
+        return toByteArray(stream,
+                length > Integer.MAX_VALUE ? Integer.MAX_VALUE : (int) length,
+                maxLength, true, length != Integer.MAX_VALUE);
+    }
+
     /**
      * Reads the input stream, and returns the bytes read.
      *
@@ -227,15 +256,12 @@ public final class IOUtils {
 
     private static byte[] toByteArray(InputStream stream, final int length, final int maxLength,
                                       final boolean checkEOFException, final boolean isLengthKnown) throws IOException {
-        if (length < 0 || maxLength < 0) {
-            throw new RecordFormatException("Can't allocate an array of length < 0");
-        }
         final int derivedMaxLength = Math.max(maxLength, BYTE_ARRAY_MAX_OVERRIDE);
         if ((length != Integer.MAX_VALUE) || (derivedMaxLength != Integer.MAX_VALUE)) {
             checkLength(length, derivedMaxLength);
         }
 
-        final int derivedLen = isLengthKnown ? Math.min(length, derivedMaxLength) : derivedMaxLength;
+        final int derivedLen = isLengthKnown && length >= 0 ? Math.min(length, derivedMaxLength) : derivedMaxLength;
         final int byteArrayInitLen = calculateByteArrayInitLength(isLengthKnown, length, derivedMaxLength);
         final int internalBufferLen = DEFAULT_BUFFER_SIZE;
         try (UnsynchronizedByteArrayOutputStream baos = UnsynchronizedByteArrayOutputStream.builder().setBufferSize(byteArrayInitLen).get()) {
@@ -254,7 +280,7 @@ public final class IOUtils {
                 throwRecordTruncationException(derivedMaxLength);
             }
 
-            if (checkEOFException && derivedLen != Integer.MAX_VALUE && totalBytes < derivedLen) {
+            if (checkEOFException && length >= 0 && derivedLen != Integer.MAX_VALUE && totalBytes < derivedLen) {
                 throw new EOFException("unexpected EOF - expected len: " + derivedLen + " - actual len: " + totalBytes);
             }
 
@@ -575,7 +601,6 @@ public final class IOUtils {
         return Arrays.copyOfRange(src, offset, offset+realLength);
     }
 
-
     /**
      * Simple utility function to check that you haven't hit EOF
      * when reading a byte.
@@ -592,6 +617,28 @@ public final class IOUtils {
         return b;
     }
 
+    /**
+     * Creates a new file in the given parent directory with the given name.
+     * There is a check to prevent path traversal attacks. Only path traversal
+     * that would lead to a file outside the parent directory is regarded as an issue.
+     *
+     * @param parent The parent directory where the file should be created.
+     * @param name The name of the file to create.
+     * @return The created file.
+     * @throws IOException If path traversal is detected.
+     * @since POI 5.5.0
+     */
+    public static File newFile(final File parent, final String name) throws IOException {
+        final File file = new File(parent, name);
+        if (!file.toPath().toAbsolutePath().normalize().startsWith(
+                parent.toPath().toAbsolutePath().normalize()
+        )) {
+            throw new IOException(String.format(
+                    Locale.ROOT, "Failing due to path traversal in `%s`", name));
+        }
+        return file;
+    }
+
     private static void throwRFE(long length, int maxLength) {
         throw new RecordFormatException(String.format(Locale.ROOT, "Tried to allocate an array of length %,d" +
                         ", but the maximum length for this record type is %,d.%n" +
